@@ -37,10 +37,10 @@ class DeleteDBNodesRequest(RpcRequest):
 	def set_ResourceOwnerId(self,ResourceOwnerId):
 		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
 
-	def get_DBNodeIds(self):
-		return self.get_query_params().get('DBNodeIds')
+	def get_DBNodeId(self):
+		return self.get_query_params().get('DBNodeId')
 
-	def set_DBNodeIds(self, DBNodeIds):
+	def set_DBNodeId(self, DBNodeIds):
 		for depth1 in range(len(DBNodeIds)):
 			if DBNodeIds[depth1] is not None:
 				self.add_query_param('DBNodeId.' + str(depth1 + 1) , DBNodeIds[depth1])
